Module: Simpleurlcount
- Defined in:
- lib/simpleurlcount.rb,
lib/simpleurlcount/version.rb
Constant Summary collapse
- VERSION =
"0.1.1"
Class Method Summary collapse
- .count_daily_url(url = '', date) ⇒ Object
- .full_title(page_title = '') ⇒ Object
- .hi ⇒ Object
- .string_message(str = '') ⇒ Object
Class Method Details
.count_daily_url(url = '', date) ⇒ Object
25 26 27 28 |
# File 'lib/simpleurlcount.rb', line 25 def self.count_daily_url(url= '', date) # get list of urls where given date exists in list # what is the size of the result end |
.full_title(page_title = '') ⇒ Object
8 9 10 11 12 13 14 15 |
# File 'lib/simpleurlcount.rb', line 8 def self.full_title(page_title = '') base_title = "Ruby on rails tutorial sample app" if page_title.empty? base_title else page_title + " | " + base_title end end |
.hi ⇒ Object
4 5 6 |
# File 'lib/simpleurlcount.rb', line 4 def self.hi puts "Hello world!" end |
.string_message(str = '') ⇒ Object
17 18 19 20 21 22 23 |
# File 'lib/simpleurlcount.rb', line 17 def self.(str = '') if str.empty? "It is empty string" else "It isnt empty" end end |